/*******************************************************************************/
/*                                                                             */
/*    Copyright (c) 2007 Analog Devices, Inc.  All Rights Reserved.            */
/*    This software is proprietary to Analog Devices, Inc. and its 			   */
/*	  licensors.                                  							   */
/*                                                                             */
/*    CHANGES:  07/02/2007  1.00  - initial public release  				   */
/*																			   */
/*******************************************************************************/

/*********************************************************************

Include files

*********************************************************************/
#include "main.h"
#include "system.h"

/*
	Function:void InitPPI1(bool, tDMA_descriptor*, short, short)
	
	Description: Initialize PP1. Configured as TX.
*/
	
void InitPPI1(bool pack32, tDMA_descriptor* First_Header, short pixel, short lines)
{ 
    short transfer_length_bytes = ((pack32) ? 4 : 1);

	// configure Timer10 for PPI frame sync - not enabled yet
	*pTMRS4_DISABLE |= TIMDIS10;						//disable Timer
	*pTMRS4_STATUS |= (TIMIL10 | TOVL_ERR10 | TRUN10);	// clear status

	*pTIMER10_PERIOD = pixel * sizeof(short);
	*pTIMER10_WIDTH = 0x10;		// some small dutycycle
	*pTIMER10_CONFIG   = TIN_SEL | PWM_OUT | PULSE_HI | PERIOD_CNT | CLK_SEL | EMU_RUN;	
	ssync();
	
	// configure PPI1 - not enabled yet
	*pPPI1_CONTROL = PORT_DIR | XFR_TYPE | (pack32 << 7)| (pack32 << 8);
	*pPPI1_COUNT = pixel * sizeof(short);					// 2 bytes for each pixel
	ssync();
	// configure DMA for PPI1 - not enabled yet
	*pDMA1_1_X_COUNT = pixel * sizeof(short) / transfer_length_bytes;	// 2 bytes for each pixel, count divided by four if 32-bit DMA transfers are done
	*pDMA1_1_Y_COUNT = lines;
	*pDMA1_1_X_MODIFY = transfer_length_bytes;		
	*pDMA1_1_Y_MODIFY = transfer_length_bytes;		
	*pDMA1_1_NEXT_DESC_PTR = First_Header;
	*pDMA1_1_CONFIG = 0x7000 | 0x0400 | DI_EN | DMA2D | (pack32 << 3);
	
	ssync();
	
}

/*
	Function:void DisablePPI1()
	
	Description:
*/
void DisablePPI1()
{
    // stop transfers
    *pTMRS4_ENABLE &= ~TIMEN10;
    ssync();
    *pPPI1_CONTROL &= ~PORT_EN;
    ssync();
    *pDMA1_1_CONFIG &= ~DMAEN;
    ssync();
}
/*
	Function:void EnablePPI1()
	
	Description:
*/
void EnablePPI1()
{
    // start transfers
    *pDMA1_1_CONFIG |= DMAEN;
    ssync();
    *pPPI1_CONTROL |= PORT_EN;
    ssync();
    *pTMRS4_ENABLE |= TIMEN10;
  	ssync();
}

/*
	Function:void InitPPI1(bool, tDMA_descriptor*, short, short)
	
	Description: Initialize PP1. Configured as TX.
*/
void InitPPI0(bool entire_field, bool pack32, tDMA_descriptor* First_Header, short pixel, short lines)
{ short transfer_length_bytes = ((pack32) ? 4 : 1);

	// configure PPI0 - not enabled yet
	*pPPI0_CONTROL = (entire_field << 2) | FLD_SEL | (pack32 << 7)| (pack32 << 8);
	*pPPI0_FRAME = lines;
	ssync();

	// configure DMA for PPI0 - not enabled yet
	*pDMA1_0_X_COUNT = pixel * sizeof(short) / transfer_length_bytes;	// 2 bytes for each pixel, count divided by four if 32-bit DMA transfers are done
	*pDMA1_0_Y_COUNT = lines;
	*pDMA1_0_X_MODIFY = transfer_length_bytes;		
	*pDMA1_0_Y_MODIFY = transfer_length_bytes;		
	*pDMA1_0_NEXT_DESC_PTR = First_Header;
	*pDMA1_0_CONFIG = 0x7000 | 0x0400 | DI_EN | DMA2D | (pack32 << 3) | WNR;
	
	ssync();
	
}

/*
	Function:void DisablePPI0(void)
	
	Description:
*/
void DisablePPI0(void)
    {
    // disable transfers
    *pPPI0_CONTROL &= ~PORT_EN;
    ssync();
    *pDMA1_0_CONFIG &= ~DMAEN;
    ssync();
    }

/*
	Function:void EnablePPI0(void)
	
	Description:
*/
void EnablePPI0(void)
    {
    // enable transfers
    *pDMA1_0_CONFIG |= DMAEN;
    ssync();
    *pPPI0_CONTROL |= PORT_EN;
    ssync();
    }
